==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/FunnelDataContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FunnelDataContextDescription } from "./FunnelDataContextDescription";
/**
 * @hidden
 */
export let FunnelDataContextDescriptionMetadata = /*@__PURE__*/ (() => {
    class FunnelDataContextDescriptionMetadata extends Base {
        static b(a) {
            if (FunnelDataContextDescriptionMetadata.a == null) {
                FunnelDataContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                FunnelDataContextDescriptionMetadata.c(FunnelDataContextDescriptionMetadata.a);
            }
            if (a.j(FunnelDataContextDescriptionMetadata.a)) {
                return;
            }
            a.y(FunnelDataContextDescriptionMetadata.a);
        }
        static c(a) {
            a.item("ItemRef", "(w:Item,wf:Item)DataRef");
            a.item("Index", "Number:int");
        }
        static d(a) {
            FunnelDataContextDescriptionMetadata.b(a);
            a.aa("FunnelDataContext", () => new FunnelDataContextDescription());
            a.z("FunnelDataContext", FunnelDataContextDescriptionMetadata.a);
        }
    }
    FunnelDataContextDescriptionMetadata.$t = /*@__PURE__*/ markType(FunnelDataContextDescriptionMetadata, 'FunnelDataContextDescriptionMetadata');
    FunnelDataContextDescriptionMetadata.a = null;
    return FunnelDataContextDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/FunnelDataContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FunnelDataContextDescription } from "./FunnelDataContextDescription";
/**
 * @hidden
 */
export let FunnelDataContextDescriptionMetadata = /*@__PURE__*/ (() => {
    class FunnelDataContextDescriptionMetadata extends Base {
        static b(a) {
            if (FunnelDataContextDescriptionMetadata.a == null) {
                FunnelDataContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                FunnelDataContextDescriptionMetadata.c(FunnelDataContextDescriptionMetadata.a);
            }
            if (a.k(FunnelDataContextDescriptionMetadata.a)) {
                return;
            }
            a.aa(FunnelDataContextDescriptionMetadata.a);
        }
        static c(a) {
            a.item("ItemRef", "(w:Item,wf:Item)DataRef");
            a.item("Index", "Number:int");
        }
        static d(a) {
            FunnelDataContextDescriptionMetadata.b(a);
            a.ac("FunnelDataContext", () => new FunnelDataContextDescription());
            a.ab("FunnelDataContext", FunnelDataContextDescriptionMetadata.a);
        }
    }
    FunnelDataContextDescriptionMetadata.$t = /*@__PURE__*/ markType(FunnelDataContextDescriptionMetadata, 'FunnelDataContextDescriptionMetadata');
    FunnelDataContextDescriptionMetadata.a = null;
    return FunnelDataContextDescriptionMetadata;
})();
